# OnlyFans Hoewave

OnlyFans is currently the most available and appropriate tool for selling your attention to others online. It provides a monthly subscription model for fans/followers to view your private collection of images, galleries, or videos. Anyone over the age of 18 can post anything they want including legal sexual acts with others. OnlyFans messaging provides a way to charge individual fans/followers for private images sent directly to them. OnlyFans is also currently rolling out a live feature, though it does not provide any 'coin' or 'tipping' functionality with it.

Ergo, OnlyFans is the #1 method to sell your own content to thirsty dudes at this time.

Instahoes and IG "Models" should be using this or a similiar platform to bolster their monthly income at zero cost to themselves. Due to how easy it is to lose an Instagram account, Instagram was not built for and is not designed as a safe source of income for anyone and everyone. It would be far more difficult to lose an OnlyFans account as an OnlyFans account is inherently designed to be used as a stable source of income.

Do you:
 - take tons of selfies

That's it. That's what everyone wants to see. Clothes on, clothes off - you'll make money if you take photographs of yourself doing what you enjoy the most.

Setting up an account is as easy as linking a Twitter account. After linking a Twitter account to an OnlyFans account, OnlySnarf is able to prepare an account for 'Quick Setup'. Options include:
 - Public Profile
 - Private Profile
 - Block USA
 - Block Hometown
 - Quiet Profile -> disables all notifications
 - Gold Digger -> tips only notifications, public but hide friend count, about lists prices

## Market Options & Rates
These are some standard image requests that you will need to set your own prices for. Never charge less than your listed rates and always respect yourself first. Everyone has their own limits and fans not capable of respecting your limits should be blocked or banned from contacting you.  
  * Feet pics
  * Videos
  * Lewds
  * Cosplay
  * Cosplay Lewds
  * Nudes

## Fan Management
Comments
Comments can be disabled. Comments should be enabled to allow an easier way to receive feedback from fans. Negative comments should lead you to fans that should be blocked or muted.
Messages  
Messages allow your fans to contact you directly. No one is entitled to a response and anyone who makes you feel uncomfortable can be blocked or muted. Messages allow you to send PayPerView messages, or messages that the fan must pay to view. This amount can be anywhere from $3 - $200 per image.

## Account Settings
IP Blocking
OnlyFans also provides basic and geographic IP blocking. Geo IP blocking allows an account to select any number of countries from a list and prevent any users in those countries from viewing or subscribing to your profile. Basic IP Blocking allows an account to block specific known ip addresses.

##Key Settings
Profile:
- displayName -> fake | stage name
- username -> page appropriate
- about -> avoid personal information
- location -> not real
- site url -> twitter
- notification settings -> minimal | tips on only
- private account -> hide post text
- enable comments
- public friends list count
- watermarking

